@@ -48,9 +48,6 @@ system_buf_addr=__get_phy_buf_addr()
 system_buf_size=__get_phy_buf_size()
 
 class axilite:
-    size = -1
-    mem = None
-    fd = -1
     def __init__(self,addr=0,size=0x1000):
         if addr%mmap.PAGESIZE != 0:
             raise Exception('The address you want to map is not page aligned, exiting!')
@@ -109,11 +106,6 @@ class axilite:
             self.fd = -1
 
 class phy_buf:
-    size = system_buf_size
-    mem = None
-    mem_fd = -1
-    phy_addr = system_buf_addr
-    offset = 0
     def __init__(self,offset=0,size=system_buf_size):
         if size+offset > system_buf_size:
             raise Exception('System has in total '+ str(system_buf_size) +' bytes reserve memory, requsting buffer is beyond that edge, exiting!')
@@ -163,11 +155,6 @@ class phy_buf:
             self.mem_fd = -1
 
 class axidma:
-    axil = None
-    phy_buf = None
-    bufsize = system_buf_size
-    dma_bufsize = 2**26
-    ps_phy_addr = system_buf_addr
     def __init__(self,axil_offset=0,buf_size=system_buf_size,buf_offset=0,dma_buflen=26):
         self.axil = axilite(axil_offset)
         self.phy_buf = phy_buf(buf_offset,buf_size)
@@ -178,14 +165,16 @@ class axidma:
         return self.phy_buf.write(raw_bytes,offset)
     def buf_read(self,size,offset=0):
         return self.phy_buf.read(size,offset)
+    def is_idle(self):
+        isIdle = getbit(self.axil.read32(SR_ADDR),0) or getbit(self.axil.read32(SR_ADDR),1) #halt or idle
+        return isIdle
     def __mm2s(self,addr,size,timeout,sync):
         CR_ADDR = 0x0
         SR_ADDR = 0x4
         SA_ADDR = 0x18
         LEN_ADDR = 0x28
         for i in range(timeout):
-            isIdle = getbit(self.axil.read32(SR_ADDR),0) or getbit(self.axil.read32(SR_ADDR),1) #halt or idle 
-            if isIdle == 1:
+            if self.is_idle() == 1:
                 break
             else:
                 time.sleep(0.001)
@@ -201,8 +190,7 @@ class axidma:
         self.axil.write32(newCtrlVal,CR_ADDR) #set start to 0
         if sync:
             for i in range(timeout):
-                isIdle = getbit(self.axil.read32(SR_ADDR),0) or getbit(self.axil.read32(SR_ADDR),1) #halt or idle 
-                if isIdle == 1:
+                if self.is_idle() == 1:
                     break
                 else:
                     time.sleep(0.001)
@@ -216,8 +204,7 @@ class axidma:
         DA_ADDR = 0x48
         LEN_ADDR = 0x58
         for i in range(timeout):
-            isIdle = getbit(self.axil.read32(SR_ADDR),0) or getbit(self.axil.read32(SR_ADDR),1) #halt or idle
-            if isIdle == 1:
+            if self.is_idle() == 1:
                 break
             else:
                 time.sleep(0.001)
@@ -233,8 +220,7 @@ class axidma:
         self.axil.write32(newCtrlVal,CR_ADDR) #set start to 0
         if sync:
             for i in range(timeout):
-                isIdle = getbit(self.axil.read32(SR_ADDR),0) or getbit(self.axil.read32(SR_ADDR),1) #halt or idle
-                if isIdle == 1:
+                if self.is_idle() == 1:
                     break
                 else:
                     time.sleep(0.001)
@@ -278,10 +264,12 @@ class axidma:
             self.axil = None
 
 class axicdma:
-    axil = None
-    dma_bufsize = 2**23
     def __init__(self,axil_offset=0):
         self.axil = axilite(axil_offset)
+        self.dma_bufsize = 2**23
+    def is_idle(self):
+        isIdle = getbit(self.axil.read32(SR_ADDR),1) #idle
+        return isIdle
     def __movedata(self,src_addr,dst_addr,size,timeout,sync):
         CR_ADDR = 0x0
         SR_ADDR = 0x4
@@ -289,8 +277,7 @@ class axicdma:
         DA_ADDR = 0x20
         LEN_ADDR = 0x28
         for i in range(timeout):
-            isIdle = getbit(self.axil.read32(SR_ADDR),1) #idle
-            if isIdle == 1:
+            if self.is_idle() == 1:
                 break
             time.sleep(0.001)
             print(i)
@@ -305,8 +292,7 @@ class axicdma:
         self.axil.write32(size,LEN_ADDR) #transfer size
         if sync:
             for i in range(timeout):
-                isIdle = getbit(self.axil.read32(SR_ADDR),1) #idle
-                if isIdle == 1:
+                if self.is_idle() == 1:
                     break
                 time.sleep(0.001)
                 if i == timeout-1:
@@ -330,10 +316,6 @@ class axicdma:
             self.axil = None
 
 class fpgamem:
-    cdma = None
-    phy_buf = None
-    ps_base_addr = system_buf_addr
-    pl_base_addr = 0
     def __init__(self,cdma_offset=0,ps_buf_offset=0,ps_buf_size=system_buf_size,fpgamem_mapbase=0):
         self.cdma = axicdma(cdma_offset)
         self.phy_buf = phy_buf(ps_buf_offset,ps_buf_size)
